pub struct OpDef { /* private fields */ }Expand description
Serializable definition for dynamically loaded operations.
TODO: Define a way to construct new OpDef’s from a serialized definition.
Implementations
Sourceimpl OpDef
impl OpDef
Sourcepub fn validate_args(
&self,
args: &[Term],
var_decls: &[Term],
) -> Result<(), SignatureError>
pub fn validate_args( &self, args: &[Term], var_decls: &[Term], ) -> Result<(), SignatureError>
Check provided type arguments are valid against their extensions,
against parameters, and that no type variables are used as static arguments
(to compute_signature)
Sourcepub fn compute_signature(
&self,
args: &[Term],
) -> Result<FuncTypeBase<NoRV>, SignatureError>
pub fn compute_signature( &self, args: &[Term], ) -> Result<FuncTypeBase<NoRV>, SignatureError>
Computes the signature of a node, i.e. an instantiation of this
OpDef with statically-provided TypeArgs.
Sourcepub fn try_lower(
&self,
args: &[Term],
available_extensions: &ExtensionSet,
) -> Option<Hugr>
pub fn try_lower( &self, args: &[Term], available_extensions: &ExtensionSet, ) -> Option<Hugr>
Fallibly returns a Hugr that may replace an instance of this OpDef
given a set of available extensions that may be used in the Hugr.
Sourcepub fn extension_id(&self) -> &IdentList
pub fn extension_id(&self) -> &IdentList
Returns a reference to the extension id of this OpDef.
Sourcepub fn extension(&self) -> Weak<Extension>
pub fn extension(&self) -> Weak<Extension>
Returns a weak reference to the extension defining this operation.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns a reference to the description of this OpDef.
Sourcepub fn params(&self) -> Result<&[Term], SignatureError>
pub fn params(&self) -> Result<&[Term], SignatureError>
Returns a reference to the params of this OpDef.
Sourcepub fn add_lower_func(&mut self, lower: LowerFunc)
pub fn add_lower_func(&mut self, lower: LowerFunc)
Add a lowering function to the OpDef
Sourcepub fn add_misc(&mut self, k: impl ToString, v: Value) -> Option<Value>
pub fn add_misc(&mut self, k: impl ToString, v: Value) -> Option<Value>
Insert miscellaneous data v to the OpDef, keyed by k.
Sourcepub fn set_constant_folder(&mut self, fold: impl ConstFold + 'static)
pub fn set_constant_folder(&mut self, fold: impl ConstFold + 'static)
Set the constant folding function for this Op, which can evaluate it given constant inputs.
Sourcepub fn constant_fold(
&self,
type_args: &[Term],
consts: &[(IncomingPort, Value)],
) -> Option<Vec<(OutgoingPort, Value)>>
pub fn constant_fold( &self, type_args: &[Term], consts: &[(IncomingPort, Value)], ) -> Option<Vec<(OutgoingPort, Value)>>
Evaluate an instance of this OpDef defined by the type_args, given
crate::ops::Const values for inputs at crate::IncomingPorts.
Sourcepub fn signature_func(&self) -> &SignatureFunc
pub fn signature_func(&self) -> &SignatureFunc
Returns a reference to the signature function of this OpDef.