pub type EdgeCheck<N> = fn(ChildrenEdgeData<N>) -> Result<(), EdgeValidationError<N>>;Expand description
A function that checks the edges between children of a node.
Part of the OpValidityFlags struct.
pub type EdgeCheck<N> = fn(ChildrenEdgeData<N>) -> Result<(), EdgeValidationError<N>>;A function that checks the edges between children of a node.
Part of the OpValidityFlags struct.